window.Gleam.initSearch([{"doc":"sketch","title":"sketch","content":"# Sketch\n\nSketch is a module providing CSS-in-Gleam in its simpler form. Sketch does not\ntry to add complicated API on top of CSS. If you have CSS knowledge, you&#39;ll feel\nright at home, with all the niceties offered by Sketch, i.e. type-checking of\nsizes and push-to-browser stylesheets of your classes, as well as SSR support.\n\nSketch has currently only one run mode: directly in your browser to leverage on\nall abilities of the JS runtime. It also allows you to build three types of CSS\nclasses: dynamic ones, changing over time, static ones, compiled once at each\nrender, and memoized ones, compiled once and for all, and reused during the\nentire lifetime of the application, just like classic CSS stylesheets.\n\nSketch is thought to interact nicely with [Lustre](https://hexdocs.pm/lustre/),\nbut can also be used directly in your vanilla Gleam application or in your\nfully-featured application. This should probably only be considered to create\ncustom framework or to integrate Sketch in your favorite framework, because\nSketch has its own lifecycle to render styles. More informations can be found in\nthe docs.\n\nSketch targets both the JS and the BEAM ecosystem. You can use it transparently\nno matter the target you&#39;re using. Sketch works in frontend, backend, SSR, SSG,\nwith OTP actors or on Node. While sketch tries to be transparent, it does not\ncompromise with performances, and tries to leverage on every abilities of the\ndifferent platforms (and uses a custom renderer both for BEAM and JS, to ensures\nsparkling performances in your browser)!\n\nThe rest of this README will focus to get you started quickly with a lustre\nexample, and some details on the available functions. If you want to know more\non how sketch is working, how to use lustre with SSR or SSG, heads up to the\ndocumentation directly! Bonus: if you&#39;re using server components, just follow\nthis guide, everything will be working directly!\n\n## Installation\n\nSketch is published on [Hex](https://hex.pm/packages/sketch). Add it to your\nproject by using the gleam CLI.\n\n```bash\ngleam add sketch\n```\n\n## Setup\n\nIf you&#39;re using Lustre (which is strongly recommended), you can just use the\n[`sketch/lustre.setup`](https://hexdocs.pm/sketch/sketch/lustre.html#setup)\nfunction and\n[`sketch/lustre.compose`](https://hexdocs.pm/sketch/sketch/lustre.html#compose)\nfunction.\n\nOtherwise, you have to follow the lifecycle of Sketch, and use the three\nlow-level functions\n[`create_cache`](https://hexdocs.pm/sketch/sketch.html#create_cache),\n[`prepare`](https://hexdocs.pm/sketch/sketch.html#prepare) and\n[`render`](https://hexdocs.pm/sketch/sketch.html#render). Create the cache with\n[`create_cache`](https://hexdocs.pm/sketch/sketch.html#create_cache) and before\nevery repaint of your application, call\n[`prepare`](https://hexdocs.pm/sketch/sketch.html#prepare). After the repaint,\nsynchronously, call [`render`](https://hexdocs.pm/sketch/sketch.html#render),\nand let the magic happen. Heads up in the docs for more details.\n\n## Example with Lustre — Frontend\n\n```gleam\nimport gleam/int\nimport lustre\nimport lustre/element/html\nimport lustre/event\nimport sketch\nimport sketch/lustre as sketch_lustre\nimport sketch/media\nimport sketch/options as sketch_options\nimport sketch/size.{px}\n\npub type Model =\n  Int\n\npub type Msg {\n  Increment\n  Decrement\n}\n\npub fn main() {\n  let init = fn(_) { 0 }\n\n  let assert Ok(cache) =\n    sketch_options.document()\n    |&gt; sketch_lustre.setup()\n\n  let assert Ok(_) =\n    view\n    |&gt; sketch_lustre.compose(cache)\n    |&gt; lustre.simple(init, update, _)\n    |&gt; lustre.start(&quot;#app&quot;, Nil)\n}\n\nfn update(model: Model, msg: Msg) {\n  case msg {\n    Increment -&gt; model + 1\n    Decrement -&gt; model - 1\n  }\n}\n\nfn main_class() {\n  sketch.class([\n    sketch.background(&quot;red&quot;),\n    sketch.display(&quot;flex&quot;),\n    sketch.flex_direction(&quot;row&quot;),\n    sketch.gap(px(12)),\n    sketch.padding(px(12)),\n    sketch.hover([sketch.background(&quot;yellow&quot;)]),\n    sketch.media(media.max_width(px(450)), [\n      sketch.background(&quot;purple&quot;),\n      sketch.hover([sketch.background(&quot;white&quot;)]),\n    ]),\n  ])\n  |&gt; sketch.to_lustre()\n}\n\nfn color_class(model: Model) {\n  let back = case model % 3 {\n    0 -&gt; &quot;blue&quot;\n    _ -&gt; &quot;green&quot;\n  }\n  let id = &quot;color-&quot; &lt;&gt; back\n  sketch.dynamic(id, [sketch.background(back)])\n  |&gt; sketch.to_lustre()\n}\n\nfn button_class() {\n  [sketch.cursor(&quot;crosshair&quot;), sketch.font_size(px(14))]\n  |&gt; sketch.class()\n  |&gt; sketch.to_lustre()\n}\n\nfn view(model: Model) {\n  html.div([main_class()], [\n    html.button([event.on_click(Decrement), button_class()], [html.text(&quot; - &quot;)]),\n    html.div([color_class(model)], [html.text(int.to_string(model))]),\n    html.button([event.on_click(Increment), button_class()], [html.text(&quot; + &quot;)]),\n  ])\n}\n```\n\n## Compiling static classes\n\nSketch exposes a single function\n[`class`](https://hexdocs.pm/sketch/sketch.html#class) allowing you to build\nyour class. The first time your function is called, the corresponding styles\nwill be compiled into CSS rules, and pushed in your browser or your `&lt;style&gt;`\nstylesheet. Every time you&#39;ll call the function during the render, no\ncomputation will be done, the class name will be returned, thanks to virtual\nstylesheet.\n\n```gleam\nimport sketch\n\nfn my_class() -&gt; String {\n  sketch.class([\n    sketch.display(&quot;flex&quot;),\n    sketch.flex_direction(&quot;column&quot;),\n  ])\n  |&gt; sketch.to_class_name()\n}\n```\n\n## Compiling dynamic classes\n\nSketch exposes another function\n[`dynamic`](https://hexdocs.pm/sketch/sketch.html#dynamic) allowing you to build\na dynamic class, changing over time. The first time the function is called, the\nproperties in the declaration will be compiled into CSS, and a class with the\nname of the ID will be pushed in the browser. When a class with the same ID is\nfound once again during the render, it will be kept, and reused. `dynamic`\nallows you to build different dynamic classes, with different ID. When you&#39;re\ngenerating the ID, if it does not exists in the stylesheet, it will be pushed in\nit, and kept at least till the next render. While a `class` function generates\n_one_ class at every render, a `dynamic` function generates _multiple_ classes\nat every render.\n\nAn ID _should be provided_ at the moment, because the runtime is unable to\ndistinguish between the dynamic classes, or at a high cost during computations:\nfinding the ID of the new class to generate _is_ a hard task by itself. While a\nsolution is awaited to be found, be careful to provide a unique id for your\ndynamic class.\n\n```gleam\nimport gleam/bool\nimport sketch\n\nfn my_dynamic_class(is_column: Bool) -&gt; String {\n  // id is unfortunately required at the moment.\n  let id = &quot;column-&quot; &lt;&gt; bool.to_string(is_column)\n  sketch.dynamic(id, [\n    sketch.display(&quot;flex&quot;),\n    case is_column {\n      True -&gt; sketch.flex_direction(&quot;column&quot;)\n      False -&gt; sketch.flex_direction(&quot;row&quot;)\n    }\n  ])\n  |&gt; sketch.to_class_name()\n}\n```\n\n## Memoizing a class\n\nSketch exposes a way to memoize a class:\n[`memo`](https://hexdocs.pm/sketch/sketch.html#memo). `memo` allows to keep a\ngenerated class _for ever_. When called on a class, sketch will preserves the\nclass for ever, and will includes the class in every render, as long as the\nvirtual stylesheet exists. This allows to skip all computations work for every\nclass computations later, and to increase performances render. _Be careful, a\nclass marked as `memo` will be then considered immutable and can never change._\n\n## Using media queries and pseudo-selectors\n\nBecause we&#39;re in CSS-in-Gleam, we can leverage on the full CSS power, contrarily\nto inline styling. This mean we can use media queries and pseudo-selectors! You\nonly need to call the proper functions, and sketch will take care of the rest.\n\n```gleam\nimport sketch\nimport sketch/media\nimport sketch/size.{px}\n\nfn my_class() {\n  sketch.class([\n    sketch.display(&quot;flex&quot;),\n    sketch.flex_direction(&quot;row&quot;),\n    sketch.background(&quot;red&quot;),\n    sketch.hover([\n      sketch.background(&quot;blue&quot;),\n    ]),\n    sketch.media(media.max_width(px(320)), [\n      sketch.flex_direction(&quot;column&quot;),\n      sketch.hover([\n        sketch.background(&quot;green&quot;),\n      ]),\n    ]),\n  ])\n  |&gt; sketch.to_lustre()\n}\n```\n\nThe example above will be compiled to the following CSS.\n\n```css\n.css-001 {\n  display: flex;\n  flex-direction: row;\n  background: red;\n}\n\n.css-001:hover {\n  background: blue;\n}\n\n@media (max-width: 320px) {\n  .css-001 {\n    flex-direction: column;\n  }\n\n  .css-001:hover {\n    background: green;\n  }\n}\n```\n\n## Usage with Lustre — Details\n\n[Lustre](https://hexdocs.pm/lustre/) is the recommended framework for frontend\ndevelopment in Gleam. Sketch tries to simplify as much the development with\nLustre. That&#39;s why Sketch exposes a\n[`setup`](https://hexdocs.pm/sketch/sketch/lustre.html#setup) function. This\nfunction creates a cache, and returns it. Another function,\n[`compose`](https://hexdocs.pm/sketch/sketch/lustre.html#compose) allows to\neasily compose the cache with the view function of Lustre. It acts as a &quot;hook&quot;\n(lustre does not officially supports hooks right now): it setups the cache\nbefore the view, and render the stylesheet after the view has executed. It tries\nto be side-effect free in the `view` in order to have a predictable render in\nLustre, and stick with the Elm architecture mindset.\n\nOnce setuped, you can use classes in your Lustre views:\n[`to_lustre()`](https://hexdocs.pm/sketch/sketch.html#to_lustre). Just use it in\nplace of\n[`to_class_name()`](https://hexdocs.pm/sketch/sketch.html#to_class_name) to get\na Lustre attribute and use it in your views.\n\n```gleam\nimport gleam/list\nimport lustre/element/html\nimport sketch\n\n// With a pipeline.\nfn my_view() {\n  [sketch.background(&quot;red&quot;)]\n  |&gt; sketch.class()\n  |&gt; sketch.to_lustre()\n  |&gt; list.repeat(1)\n  |&gt; html.div(_, [])\n}\n\n// With a dynamic class.\nfn my_other_view(model: Bool) {\n  let color = case model {\n    True -&gt; &quot;red&quot;\n    False -&gt; &quot;blue&quot;\n  }\n  let id = &quot;my-other-view-&quot; &lt;&gt; color\n  html.div(\n    [sketch.to_lustre(sketch.dynamic(id, [sketch.background(color)]))],\n    [],\n  )\n}\n```\n\n## Use with Shadow DOM\n\nSketch can work with a Shadow DOM, in order to hide the compiled styles from the\nrest of the application. To do it, you can use\n[`plinth`](https://github.com/CrowdHailer/plinth). This allows to create a\n`ShadowRoot`, to use\n[`sketch/options.shadow_root()`](https://hexdocs.pm/sketch/sketch/options.html#shadow_root).\nIn the same way you can initialize the cache to render in document or in a\n`style` node, you can now use a Shadow Root to paint styles in your application!\n\n## Some opinions on properties\n\nA lot of properties are accessible directly through the `sketch` package. But\nwith time, some could be added, and new features for existing features can\nappear. That&#39;s why sketch will never try to be on your way: at any time you can\naccess [`property()`](https://hexdocs.pm/sketch/sketch.html#property), which\nallows you to push any arbitrary property in a class. Another thing is ç that\nsketch will always let you access raw, low-level properties. If you&#39;re trying to\nuse something like `sketch.width(&quot;auto&quot;)` and the property does not support\nString, look for a variant with an underscore (`_`), it should fullfill your\nneeds, like `sketch.width_(&quot;auto&quot;)`! In case something is missing or a property\ndoes not have its underscore alternative,\n[open an issue — or better, a PR — on the repo!](https://github.com/ghivert/sketch)\n","url":"index.html"},{"doc":"sketch","title":"sketch","content":"","url":"#"},{"doc":"sketch","title":"sketch","content":"# Internal details\n\nSketch tries to be to CSS what the VDOM is to the DOM: the ultimate pain-free\ntool to manage the state of your CSS styles, without having to worry with CSS\nwhile leveraging CSS skills.\n\n## I don&#39;t know anything about Sketch!\n\nThis documentation focuses on internal and how is working Sketch under-the-hood.\nNo worry though, just heads up to the [README](https://hexdocs.pm/sketch) to get\nan overview of Sketch, and to get it work with your favorite framework!\n\n## Lifecycle\n\nTo do this, Sketch tries to maintain a cache of styles, that can be updated\nbetween every render of the DOM, and will update the correct StyleSheet in DOM.\nIt can be viewed as a virtual stylesheet, in the same way lustre uses a virtual\nDOM under the hood to maintain the DOM. In sketch, it&#39;s called a &quot;cache&quot;.\n\nSketch has a lifecycle to make it work. After having created a Cache, you have\nto call `prepare` before every repaint, and `render` after every repaint.\n\n```txt\n                            +--------------+\n                            | Create Cache |\n                            +--------------+\n                                   |\n                                   |\n                                   |\n                                   v\n                    +-------------------------------+\n                    | Before paint, setup the cache |  &lt;-------+\n                    +-------------------------------+          |\n                                   |                           |\n                                   |                           |\n                                   |                           |\n                                   v                           |\n              +-------------------------------------------+    |\n              |                                           |    |\n              |      framework paints to the DOM          |    |\n              |   and calls class and dynamic functions   |    |\n              |            provided by sketch             |    |\n              |                                           |    |\n              +-------------------------------------------+    |\n                                   |                           |\n                                   |                           |\n                                   |                           |\n                                   v                           |\n                    +-------------------------------+          |\n                    | After paint, render the cache |  --------+\n                    +-------------------------------+\n```\n\n- `prepare` setup the Cache in order to diff the old styles with the new styles.\n  If `prepare` is not called before every repaint, the stylesheet will not diff\n  styles, and it will continue to append styles to the stylesheet.\n\n- `render` accepts the cache and will inject the stylesheet in the DOM or the\n  document in the browser, and will returns the stylesheet as a string on BEAM.\n\n## Different architectures\n\nSketch differs a little bit according to the runtime it&#39;s running on. Sketch has\ntwo different runtimes: the first with an (almost) pure gleam implementation,\nthe second with a native JS implementation, to avoid bad async behaviors and to\nmaintain high performance.\n\n### Global overview\n\n```txt\n                                  +--------------+\n                                  | Create Cache |\n                                  +--------------+\n                                         |\n                                         |\n                                         |\n                                         v\n                          +-------------------------------+\n                          | Before paint, setup the cache |  &lt;----------------------+\n                          +-------------------------------+                         |\n                               |                     |                              |\n                               |                     |                              |\n                               |                     |                              |\n                               v                     v                              |\n+ JS ---------------------------------+   + BEAM ------------------------------+    |\n|                                     |   |                                    |    |\n|     Stores the cache globally       |   |      Stores the cache by actor     |    |\n|      just before the render         |   |           in an ETS table          |    |\n|                                     |   |                                    |    |\n+-------------------------------------+   +------------------------------------+    |\n                   |                                         |                      |\n                   |                                         |                      |\n                   |                                         |                      |\n                   v                                         v                      |\n+ JS ---------------------------------+   + BEAM ------------------------------+    |\n|                                     |   |                                    |    |\n|   Gleam generates HTML and calls    |   |   Gleam generates HTML and calls   |    |\n|    class and dynamic functions      |   |    class and dynamic functions     |    |\n|      provided by sketch using       |   |      provided by sketch using      |    |\n|     native implementation in JS     |   |   an OTP actor and gleam implem    |    |\n|                                     |   |                                    |    |\n+-------------------------------------+   +------------------------------------+    |\n                   |                                          |                     |\n                   |                                          |                     |\n                   |                                          |                     |\n                   v                                          v                     |\n     + JS -----------------------+              +---------------------------+       |\n     |  After paint, render the  |              |  After paint, render the  |       |\n     |    cache on browser       |              |    cache with browser     |       |\n     +---------------------------+              +---------------------------+       |\n               |                                                |                   |\n               +------------------------------------------------+-------------------+\n```\n\nIn gleam implementation, every cache is modeled as an actor, while in JS, every\ncache is modeled as a mutable object. The algorithm is identical in both case. A\nvirtual stylesheet is made of a cache, and finally an abstract stylesheet,\nfollowing the same interface as a CSSStyleSheet on browser.\n\nEvery cache has a concept of an active and a passive class list. The active\nclass list is the list maintained during the current render. The passive class\nlist is the list from the previous render. The goal here is, every time we have\nto compute a class, to check if that class has already been computed in the last\nrender. If it is, then the class is transferred from the passive class list to\nthe active class list. At the end of render, a diff is made between the two\nlists, the new classes, created during the render and pushed to the active class\nlist are added to the stylesheet, the old styles only present in the passive\nclass list are removed from the stylesheet, and finally, the stylesheet is\nconstructed. The active class list becomes the passive class list, and the loop\nstarts again.\n\n## Some notes on side-effects\n\nUnfortunately, and because of the nature of the different frameworks and of CSS,\nSketch is doing some side-effects in background, to collect the styles and to\npush them in the browser. Maybe it could be removed in the future, but it would\ninvolve work with different maintainers of different packages, and it would take\na lot of time and energy. It&#39;s not on plan right now, but rather to focus on\ncorrect UX and to find good ways of doing things. When the dust will settle and\nthat API will be stable, then we could take some time to figure out how to get\nrid of side-effects. In the meantime, if you plan to integrate Sketch in your\nframework, and need some access to underlying and internals, open an issue with\nyour use case, I&#39;d more than happy to help on that point and reduce\nside-effects.\n","url":"internal-details.html"},{"doc":"sketch","title":"sketch","content":"# Usage with BEAM\n\nSketch can be transparently used with BEAM and JS, however, due to the runtime,\nsome differences exists, and should be taken in consideration. Contrarily to JS,\nBEAM is a runtime which is actor oriented, and synchronous.\n\nTo generate the real stylesheet the application will use, sketch uses an\nintermediate virtual stylesheet, called &quot;cache&quot;. In BEAM, each process needs to\ncreate cache.\n\nJust like with any app, creating a cache relies on\n[`create_cache`](https://hexdocs.pm/sketch/sketch.html#create_cache). Once\ncreated, a cache will live as long as you keep a reference on it. The strategy\nis to prepare and render the cache before and after every HTML generation. You\ncan use [`prepare`](https://hexdocs.pm/sketch/sketch.html#prepare) and\n[`render`](https://hexdocs.pm/sketch/sketch.html#render) respectively before and\nafter HTML generation. `prepare` will setup the cache as being the default cache\nfor the current process, and `render` will turn the cache into a proper\nstylesheet, i.e. it will returns a `String`, containing the stylesheet content.\nAll you have to do then is to embed the resulting string in your output HTML,\nand voilà!\n\n## Example\n\nThe example assumes you&#39;re using a blank, empty\n[`mist`](https://hexdocs.pm/mist) server. It could feel a little cumbersome, but\nmost of the time, your framework should handle it directly.\n\n```gleam\nimport gleam/bytes_builder\nimport gleam/erlang/process\nimport gleam/http/request.{type Request}\nimport gleam/http/response.{type Response}\nimport gleam/string\nimport mist.{type Connection, type ResponseData}\nimport sketch\nimport sketch/options as sketch_options\n\npub fn main() {\n  // Creates the cache here. A global cache will be used here, because the SSR\n  // only uses one process.\n  let assert Ok(cache) =\n    sketch_options.node()\n    |&gt; sketch.create_cache()\n\n  // Helpers for mist server.\n  let empty_body = mist.Bytes(bytes_builder.new())\n  let not_found = response.set_body(response.new(404), empty_body)\n\n  let assert Ok(_) =\n    fn(req: Request(Connection)) -&gt; Response(ResponseData) {\n      // Before every request, prepare the cache, to wipe it from old data, and\n      // mark it as &quot;default&quot; cache for the following render.\n      sketch.prepare(cache)\n      case request.path_segments(req) {\n        // Send the cache to your render function. It will be used before\n        // returing the HTML.\n        [&quot;greet&quot;, name] -&gt; greet(name, cache)\n        _ -&gt; not_found\n      }\n    }\n    |&gt; mist.new()\n    |&gt; mist.port(3000)\n    |&gt; mist.start_http()\n\n  process.sleep_forever()\n}\n\n// Defines a class, here with simple class name.\nfn main_class() {\n  [sketch.color(&quot;red&quot;)]\n  |&gt; sketch.class()\n  |&gt; sketch.to_class_name()\n}\n\nfn greet(name: String, cache: sketch.Cache) -&gt; Response(ResponseData) {\n  let res = response.new(200)\n  let greetings = &quot;&lt;div&gt;Hey there, &quot; &lt;&gt; name &lt;&gt; &quot;!&lt;/div&gt;&quot;\n\n  // Create your body, with the classes computed.\n  let body =\n    [\n      &quot;&lt;div class=&quot; &lt;&gt; main_class() &lt;&gt; &quot;&gt;&quot;,\n      &quot;  &lt;div&gt;Hello World!&lt;/div&gt;&quot;,\n      greetings,\n      &quot;&lt;/div&gt;&quot;,\n    ]\n    |&gt; string.join(&quot;\\n&quot;)\n\n  // Get the content of your stylesheet.\n  let assert Ok(stylesheet_content) = sketch.render(cache)\n\n  // Render the style in your HTML.\n  let html =\n    [\n      &quot;&lt;html&gt;&quot;,\n      &quot;  &lt;head&gt;&quot;,\n      &quot;    &lt;style&gt;&quot;,\n      stylesheet_content,\n      &quot;    &lt;/style&gt;&quot;,\n      &quot;  &lt;/head&gt;&quot;,\n      &quot;  &lt;body&gt;&quot;,\n      body,\n      &quot;  &lt;/body&gt;&quot;,\n      &quot;&lt;/html&gt;&quot;,\n    ]\n    |&gt; string.join(&quot;\\n&quot;)\n\n  html\n  |&gt; bytes_builder.from_string()\n  |&gt; mist.Bytes()\n  |&gt; response.set_body(res, _)\n}\n```\n\n## More details\n\nYou can find more details on how it works in the\n[internal details](https://hexdocs.pm/sketch/internal-details.html).\n","url":"usage-with-beam.html"},{"doc":"sketch","title":"sketch","content":"# Usage with Lustre SSR\n\nTo use sketch with lustre SSR, little modifications are necessary. Sketch\nbundles helpers to work with lustre SSR right out-of-the-box. Just use them, and\nyou&#39;ll be good to go. Like every lustre application, it has to be setuped with\n[`setup`](https://hexdocs.pm/sketch/sketch/lustre.html#setup), but after that,\nyou&#39;ll have to use [`prepare`](https://hexdocs.pm/sketch/sketch.html#prepare) in\nyour HTTP handler, and at the end of the HTML generation, when you still have an\n[`Element`](https://hexdocs.pm/lustre/lustre/element.html#Element) from lustre,\nrun [`ssr`](https://hexdocs.pm/sketch/sketch/lustre.html#ssr) and let the magic\nhappen!\n\n## Example\n\nAn example with lustre, and with SSR. The idea here is to instanciate a cache,\nand to reuses it for every request. To scale it properly, the idea would be to\ncreate a cache for every process started.\n\n```gleam\nimport gleam/bytes_builder\nimport gleam/erlang/process\nimport gleam/http/request.{type Request}\nimport gleam/http/response.{type Response}\nimport lustre/element\nimport lustre/element/html.{html}\nimport mist.{type Connection, type ResponseData}\nimport sketch\nimport sketch/lustre as sketch_lustre\nimport sketch/options as sketch_options\n\npub fn main() {\n  // Creates the cache here. A global cache will be used here, because the SSR\n  // only uses one process.\n  let assert Ok(cache) =\n    sketch_options.node()\n    |&gt; sketch_lustre.setup()\n\n  // Helpers for mist server.\n  let empty_body = mist.Bytes(bytes_builder.new())\n  let not_found = response.set_body(response.new(404), empty_body)\n\n  let assert Ok(_) =\n    fn(req: Request(Connection)) -&gt; Response(ResponseData) {\n      // Before every request, prepare the cache, to wipe it from old data, and\n      // mark it as &quot;default&quot; cache for the following render.\n      sketch.prepare(cache)\n      case request.path_segments(req) {\n        // Send the cache to your render function. It will be used before\n        // returing the HTML.\n        [&quot;greet&quot;, name] -&gt; greet(name, cache)\n        _ -&gt; not_found\n      }\n    }\n    |&gt; mist.new()\n    |&gt; mist.port(3000)\n    |&gt; mist.start_http()\n\n  process.sleep_forever()\n}\n\n// Defines a class, here with lustre SSR.\nfn main_class() {\n  [sketch.color(&quot;red&quot;)]\n  |&gt; sketch.class()\n  |&gt; sketch.to_lustre()\n}\n\nfn greet(name: String, cache: sketch.Cache) -&gt; Response(ResponseData) {\n  let res = response.new(200)\n  let greetings = &quot;Hey there, &quot; &lt;&gt; name &lt;&gt; &quot;!&quot;\n  let html =\n    html([], [\n      html.head([], [html.title([], &quot;Greetings!&quot;)]),\n      // Use the class as usual.\n      html.body([], [html.h1([main_class()], [html.text(greetings)])]),\n    ])\n\n  html\n  // Ask for sketch to inject the cache content in the resulting HTML from lustre.\n  |&gt; sketch_lustre.ssr(cache)\n  |&gt; element.to_document_string()\n  |&gt; bytes_builder.from_string()\n  |&gt; mist.Bytes()\n  |&gt; response.set_body(res, _)\n}\n```\n\n## Feedbacks\n\nBecause we lack people really using SSR, we take all feedbacks to help us\nimprove the API for SSR with sketch! Feel free to open an issue to discuss about\nthe API!\n","url":"usage-with-lustre-ssr.html"},{"doc":"sketch/error","title":"SketchError","content":"pub type SketchError {\n  NotABrowser\n}\n\nNotABrowser\n\n\nSynonyms:\nsketch/error.SketchError\nsketch/error SketchError","url":"sketch/error.html#SketchError"},{"doc":"sketch/error","title":"sketch/error","content":" Defines standard error returned by sketch.","url":"sketch/error.html"},{"doc":"sketch/options","title":"Options","content":"pub opaque type Options\n\n\nSynonyms:\nsketch/options.Options\nsketch/options Options","url":"sketch/options.html#Options"},{"doc":"sketch/options","title":"StyleSheet","content":"pub opaque type StyleSheet\n Internal use.\n\nSynonyms:\nsketch/options.StyleSheet\nsketch/options StyleSheet","url":"sketch/options.html#StyleSheet"},{"doc":"sketch/options","title":"document","content":"pub fn document() -&gt; Options\n document cannot be used on server.\nSynonyms:\nsketch/options.document\nsketch/options document","url":"sketch/options.html#document"},{"doc":"sketch/options","title":"node","content":"pub fn node() -&gt; Options\n\nSynonyms:\nsketch/options.node\nsketch/options node","url":"sketch/options.html#node"},{"doc":"sketch/options","title":"shadow","content":"pub fn shadow(root: ShadowRoot) -&gt; Options\n shadow cannot be used on server.\nSynonyms:\nsketch/options.shadow\nsketch/options shadow","url":"sketch/options.html#shadow"},{"doc":"sketch/options","title":"stylesheet_to_string","content":"pub fn stylesheet_to_string(stylesheet: StyleSheet) -&gt; String\n Internal function, can be used if you need to go from a StyleSheet to a String\n in case you&#39;re building on top of sketch. Used in FFI at the moment.\nSynonyms:\nsketch/options.stylesheet_to_string\nsketch/options stylesheet_to_string","url":"sketch/options.html#stylesheet_to_string"},{"doc":"sketch/options","title":"sketch/options","content":" Defines Options to setup the runtime of sketch.\n The Options could right now be a `style` node injected in the DOM, or on\n a CSSStyleSheet, adopted directly on the document.","url":"sketch/options.html"},{"doc":"sketch/size","title":"Size","content":"pub opaque type Size\n Size defines a CSS Unit. It can be either `px`, `pt`, `vh`, `vw`, `em`,\n `rem`, `lh`, `rlh`, `ch`, `%`. To instanciate a Size, use the corresponding\n functions. Every unit exposes two functions: the Int function (like `px(0)`)\n and the Float version suffixed by an underscore (like `px_(0.0)`).\n\nSynonyms:\nsketch/size.Size\nsketch/size Size","url":"sketch/size.html#Size"},{"doc":"sketch/size","title":"ch","content":"pub fn ch(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.ch\nsketch/size ch","url":"sketch/size.html#ch"},{"doc":"sketch/size","title":"ch_","content":"pub fn ch_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.ch_\nsketch/size ch_","url":"sketch/size.html#ch_"},{"doc":"sketch/size","title":"em","content":"pub fn em(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.em\nsketch/size em","url":"sketch/size.html#em"},{"doc":"sketch/size","title":"em_","content":"pub fn em_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.em_\nsketch/size em_","url":"sketch/size.html#em_"},{"doc":"sketch/size","title":"lh","content":"pub fn lh(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.lh\nsketch/size lh","url":"sketch/size.html#lh"},{"doc":"sketch/size","title":"lh_","content":"pub fn lh_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.lh_\nsketch/size lh_","url":"sketch/size.html#lh_"},{"doc":"sketch/size","title":"percent","content":"pub fn percent(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.percent\nsketch/size percent","url":"sketch/size.html#percent"},{"doc":"sketch/size","title":"percent_","content":"pub fn percent_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.percent_\nsketch/size percent_","url":"sketch/size.html#percent_"},{"doc":"sketch/size","title":"pt","content":"pub fn pt(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.pt\nsketch/size pt","url":"sketch/size.html#pt"},{"doc":"sketch/size","title":"pt_","content":"pub fn pt_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.pt_\nsketch/size pt_","url":"sketch/size.html#pt_"},{"doc":"sketch/size","title":"px","content":"pub fn px(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.px\nsketch/size px","url":"sketch/size.html#px"},{"doc":"sketch/size","title":"px_","content":"pub fn px_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.px_\nsketch/size px_","url":"sketch/size.html#px_"},{"doc":"sketch/size","title":"rem","content":"pub fn rem(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.rem\nsketch/size rem","url":"sketch/size.html#rem"},{"doc":"sketch/size","title":"rem_","content":"pub fn rem_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.rem_\nsketch/size rem_","url":"sketch/size.html#rem_"},{"doc":"sketch/size","title":"rlh","content":"pub fn rlh(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.rlh\nsketch/size rlh","url":"sketch/size.html#rlh"},{"doc":"sketch/size","title":"rlh_","content":"pub fn rlh_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.rlh_\nsketch/size rlh_","url":"sketch/size.html#rlh_"},{"doc":"sketch/size","title":"to_string","content":"pub fn to_string(size: Size) -&gt; String\n Internal function, can be used if you need to go from a Size to a String\n in case you&#39;re building on top of sketch.\nSynonyms:\nsketch/size.to_string\nsketch/size to_string","url":"sketch/size.html#to_string"},{"doc":"sketch/size","title":"vh","content":"pub fn vh(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.vh\nsketch/size vh","url":"sketch/size.html#vh"},{"doc":"sketch/size","title":"vh_","content":"pub fn vh_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.vh_\nsketch/size vh_","url":"sketch/size.html#vh_"},{"doc":"sketch/size","title":"vw","content":"pub fn vw(value: Int) -&gt; Size\n\nSynonyms:\nsketch/size.vw\nsketch/size vw","url":"sketch/size.html#vw"},{"doc":"sketch/size","title":"vw_","content":"pub fn vw_(value: Float) -&gt; Size\n\nSynonyms:\nsketch/size.vw_\nsketch/size vw_","url":"sketch/size.html#vw_"},{"doc":"sketch/size","title":"sketch/size","content":" Defines sizes directly with functions, to avoid conversions between int, float\n and strings.","url":"sketch/size.html"},{"doc":"sketch/media","title":"ColorMode","content":"pub opaque type ColorMode\n\n\nSynonyms:\nsketch/media.ColorMode\nsketch/media ColorMode","url":"sketch/media.html#ColorMode"},{"doc":"sketch/media","title":"Query","content":"pub opaque type Query\n\n\nSynonyms:\nsketch/media.Query\nsketch/media Query","url":"sketch/media.html#Query"},{"doc":"sketch/media","title":"and","content":"pub fn and(first: Query, second: Query) -&gt; Query\n\nSynonyms:\nsketch/media.and\nsketch/media and","url":"sketch/media.html#and"},{"doc":"sketch/media","title":"dark_theme","content":"pub fn dark_theme() -&gt; Query\n\nSynonyms:\nsketch/media.dark_theme\nsketch/media dark_theme","url":"sketch/media.html#dark_theme"},{"doc":"sketch/media","title":"landscape","content":"pub fn landscape() -&gt; Query\n\nSynonyms:\nsketch/media.landscape\nsketch/media landscape","url":"sketch/media.html#landscape"},{"doc":"sketch/media","title":"light_theme","content":"pub fn light_theme() -&gt; Query\n\nSynonyms:\nsketch/media.light_theme\nsketch/media light_theme","url":"sketch/media.html#light_theme"},{"doc":"sketch/media","title":"max_height","content":"pub fn max_height(size: Size) -&gt; Query\n\nSynonyms:\nsketch/media.max_height\nsketch/media max_height","url":"sketch/media.html#max_height"},{"doc":"sketch/media","title":"max_width","content":"pub fn max_width(size: Size) -&gt; Query\n\nSynonyms:\nsketch/media.max_width\nsketch/media max_width","url":"sketch/media.html#max_width"},{"doc":"sketch/media","title":"min_height","content":"pub fn min_height(size: Size) -&gt; Query\n\nSynonyms:\nsketch/media.min_height\nsketch/media min_height","url":"sketch/media.html#min_height"},{"doc":"sketch/media","title":"min_width","content":"pub fn min_width(size: Size) -&gt; Query\n\nSynonyms:\nsketch/media.min_width\nsketch/media min_width","url":"sketch/media.html#min_width"},{"doc":"sketch/media","title":"not","content":"pub fn not(query: Query) -&gt; Query\n\nSynonyms:\nsketch/media.not\nsketch/media not","url":"sketch/media.html#not"},{"doc":"sketch/media","title":"or","content":"pub fn or(first: Query, second: Query) -&gt; Query\n\nSynonyms:\nsketch/media.or\nsketch/media or","url":"sketch/media.html#or"},{"doc":"sketch/media","title":"portrait","content":"pub fn portrait() -&gt; Query\n\nSynonyms:\nsketch/media.portrait\nsketch/media portrait","url":"sketch/media.html#portrait"},{"doc":"sketch/media","title":"to_string","content":"pub fn to_string(query: Query) -&gt; String\n Internal function, can be used if you need to go from a media query to a String\n in case you&#39;re building on top of sketch.\nSynonyms:\nsketch/media.to_string\nsketch/media to_string","url":"sketch/media.html#to_string"},{"doc":"sketch/media","title":"sketch/media","content":" Define media queries directly with functions.\n Refer to the sketch module to get more details on the usage.\n\n ## Advanced usage\n\n Media queries can be rather complex, and the module tries to give all\n features in a usable way. A media query takes form (property: value) and\n can be combined, like (orientation: landscape or min-width: 1000px).\n Those media queries can be created by using the corresponding `and`,\n `or` or `not` functions.","url":"sketch/media.html"},{"doc":"sketch","title":"Cache","content":"pub type Cache =\n  cache.Cache\n Manages the styles. Can be instanciated with [`create_cache`](#create_cache).\n\nSynonyms:\nsketch.Cache\nsketch Cache","url":"sketch.html#Cache"},{"doc":"sketch","title":"Class","content":"pub type Class =\n  class.Class\n Represents a CSS class, compiled.\n\nSynonyms:\nsketch.Class\nsketch Class","url":"sketch.html#Class"},{"doc":"sketch","title":"Media","content":"pub type Media\n No direct usage, used for type-checking and to cancel impossible states.\n\nSynonyms:\nsketch.Media\nsketch Media","url":"sketch.html#Media"},{"doc":"sketch","title":"NoMedia","content":"pub type NoMedia\n No direct usage, used for type-checking and to cancel impossible states.\n\nSynonyms:\nsketch.NoMedia\nsketch NoMedia","url":"sketch.html#NoMedia"},{"doc":"sketch","title":"NoPseudoSelector","content":"pub type NoPseudoSelector\n No direct usage, used for type-checking and to cancel impossible states.\n\nSynonyms:\nsketch.NoPseudoSelector\nsketch NoPseudoSelector","url":"sketch.html#NoPseudoSelector"},{"doc":"sketch","title":"PseudoSelector","content":"pub type PseudoSelector\n No direct usage, used for type-checking and to cancel impossible states.\n\nSynonyms:\nsketch.PseudoSelector\nsketch PseudoSelector","url":"sketch.html#PseudoSelector"},{"doc":"sketch","title":"Style","content":"pub opaque type Style(media, pseudo)\n Represents a Style. It can be a class composition, a media query with its\n sub-properties, a pseudo-selector with its sub-properties or a property\n directly.\n It&#39;s not possible to put a media query in a media query, and a pseudo-selector\n in a pseudo-selector.\n\nSynonyms:\nsketch.Style\nsketch Style","url":"sketch.html#Style"},{"doc":"sketch","title":"active","content":"pub fn active(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.active\nsketch active","url":"sketch.html#active"},{"doc":"sketch","title":"align_content","content":"pub fn align_content(align: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.align_content\nsketch align_content","url":"sketch.html#align_content"},{"doc":"sketch","title":"align_items","content":"pub fn align_items(align: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.align_items\nsketch align_items","url":"sketch.html#align_items"},{"doc":"sketch","title":"align_self","content":"pub fn align_self(align: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.align_self\nsketch align_self","url":"sketch.html#align_self"},{"doc":"sketch","title":"align_tracks","content":"pub fn align_tracks(align: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.align_tracks\nsketch align_tracks","url":"sketch.html#align_tracks"},{"doc":"sketch","title":"animation","content":"pub fn animation(animation: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.animation\nsketch animation","url":"sketch.html#animation"},{"doc":"sketch","title":"animation_delay","content":"pub fn animation_delay(animation: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.animation_delay\nsketch animation_delay","url":"sketch.html#animation_delay"},{"doc":"sketch","title":"animation_direction","content":"pub fn animation_direction(animation: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.animation_direction\nsketch animation_direction","url":"sketch.html#animation_direction"},{"doc":"sketch","title":"animation_duration","content":"pub fn animation_duration(animation: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.animation_duration\nsketch animation_duration","url":"sketch.html#animation_duration"},{"doc":"sketch","title":"animation_fill_mode","content":"pub fn animation_fill_mode(animation: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.animation_fill_mode\nsketch animation_fill_mode","url":"sketch.html#animation_fill_mode"},{"doc":"sketch","title":"animation_iteration_count","content":"pub fn animation_iteration_count(\n  animation: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.animation_iteration_count\nsketch animation_iteration_count","url":"sketch.html#animation_iteration_count"},{"doc":"sketch","title":"animation_name","content":"pub fn animation_name(animation: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.animation_name\nsketch animation_name","url":"sketch.html#animation_name"},{"doc":"sketch","title":"animation_play_state","content":"pub fn animation_play_state(animation: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.animation_play_state\nsketch animation_play_state","url":"sketch.html#animation_play_state"},{"doc":"sketch","title":"animation_timing_function","content":"pub fn animation_timing_function(\n  animation: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.animation_timing_function\nsketch animation_timing_function","url":"sketch.html#animation_timing_function"},{"doc":"sketch","title":"appearance","content":"pub fn appearance(appearance: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.appearance\nsketch appearance","url":"sketch.html#appearance"},{"doc":"sketch","title":"aspect_ratio","content":"pub fn aspect_ratio(aspect_ratio: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.aspect_ratio\nsketch aspect_ratio","url":"sketch.html#aspect_ratio"},{"doc":"sketch","title":"background","content":"pub fn background(background: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.background\nsketch background","url":"sketch.html#background"},{"doc":"sketch","title":"blank","content":"pub fn blank(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.blank\nsketch blank","url":"sketch.html#blank"},{"doc":"sketch","title":"border","content":"pub fn border(border: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border\nsketch border","url":"sketch.html#border"},{"doc":"sketch","title":"border_bottom","content":"pub fn border_bottom(border_bottom: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_bottom\nsketch border_bottom","url":"sketch.html#border_bottom"},{"doc":"sketch","title":"border_bottom_left_radius","content":"pub fn border_bottom_left_radius(\n  border_bottom_left_radius: Size,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_bottom_left_radius\nsketch border_bottom_left_radius","url":"sketch.html#border_bottom_left_radius"},{"doc":"sketch","title":"border_bottom_left_radius_","content":"pub fn border_bottom_left_radius_(\n  border_bottom_left_radius: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_bottom_left_radius_\nsketch border_bottom_left_radius_","url":"sketch.html#border_bottom_left_radius_"},{"doc":"sketch","title":"border_bottom_right_radius","content":"pub fn border_bottom_right_radius(\n  border_bottom_right_radius: Size,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_bottom_right_radius\nsketch border_bottom_right_radius","url":"sketch.html#border_bottom_right_radius"},{"doc":"sketch","title":"border_bottom_right_radius_","content":"pub fn border_bottom_right_radius_(\n  border_bottom_right_radius: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_bottom_right_radius_\nsketch border_bottom_right_radius_","url":"sketch.html#border_bottom_right_radius_"},{"doc":"sketch","title":"border_left","content":"pub fn border_left(border_left: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_left\nsketch border_left","url":"sketch.html#border_left"},{"doc":"sketch","title":"border_radius","content":"pub fn border_radius(border_radius: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_radius\nsketch border_radius","url":"sketch.html#border_radius"},{"doc":"sketch","title":"border_radius_","content":"pub fn border_radius_(border_radius: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_radius_\nsketch border_radius_","url":"sketch.html#border_radius_"},{"doc":"sketch","title":"border_right","content":"pub fn border_right(border_right: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_right\nsketch border_right","url":"sketch.html#border_right"},{"doc":"sketch","title":"border_top","content":"pub fn border_top(border_top: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_top\nsketch border_top","url":"sketch.html#border_top"},{"doc":"sketch","title":"border_top_left_radius","content":"pub fn border_top_left_radius(\n  border_top_left_radius: Size,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_top_left_radius\nsketch border_top_left_radius","url":"sketch.html#border_top_left_radius"},{"doc":"sketch","title":"border_top_left_radius_","content":"pub fn border_top_left_radius_(\n  border_top_left_radius: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_top_left_radius_\nsketch border_top_left_radius_","url":"sketch.html#border_top_left_radius_"},{"doc":"sketch","title":"border_top_right_radius","content":"pub fn border_top_right_radius(\n  border_top_right_radius: Size,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_top_right_radius\nsketch border_top_right_radius","url":"sketch.html#border_top_right_radius"},{"doc":"sketch","title":"border_top_right_radius_","content":"pub fn border_top_right_radius_(\n  border_top_right_radius: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.border_top_right_radius_\nsketch border_top_right_radius_","url":"sketch.html#border_top_right_radius_"},{"doc":"sketch","title":"bottom","content":"pub fn bottom(size: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.bottom\nsketch bottom","url":"sketch.html#bottom"},{"doc":"sketch","title":"bottom_","content":"pub fn bottom_(size: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.bottom_\nsketch bottom_","url":"sketch.html#bottom_"},{"doc":"sketch","title":"box_shadow","content":"pub fn box_shadow(box_shadow: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.box_shadow\nsketch box_shadow","url":"sketch.html#box_shadow"},{"doc":"sketch","title":"box_sizing","content":"pub fn box_sizing(box_sizing: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.box_sizing\nsketch box_sizing","url":"sketch.html#box_sizing"},{"doc":"sketch","title":"checked","content":"pub fn checked(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.checked\nsketch checked","url":"sketch.html#checked"},{"doc":"sketch","title":"class","content":"pub fn class(styles: List(Style(a, b))) -&gt; Class\n Compiles a static class, and reuses it across the same render flow.\n Don&#39;t use dynamic styles with it, use `dynamic` instead.\nSynonyms:\nsketch.class\nsketch class","url":"sketch.html#class"},{"doc":"sketch","title":"color","content":"pub fn color(color: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.color\nsketch color","url":"sketch.html#color"},{"doc":"sketch","title":"column_gap","content":"pub fn column_gap(column_gap: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.column_gap\nsketch column_gap","url":"sketch.html#column_gap"},{"doc":"sketch","title":"compose","content":"pub fn compose(class: Class) -&gt; Style(a, b)\n Compose styles by inheriting class, and later overrides them.\n Works similarly to `composes` property in CSS modules.\nSynonyms:\nsketch.compose\nsketch compose","url":"sketch.html#compose"},{"doc":"sketch","title":"create_cache","content":"pub fn create_cache(\n  options: Options,\n) -&gt; Result(Cache, SketchError)\n Create a cache manager, managing the styles for every repaint. You can\n instanciate as much cache manager that you want, if you want to use multiple\n render lifecycle.\n You can output the styles directly in a node style in the DOM, or by pushing\n them directly in a CSSStyleSheet, at the document level. The choice is up to\n you at the initialization of the Cache.\n On BEAM, this setting is ignored.\n If you&#39;re using Lustre, you shouldn&#39;t have to worry about it, and consider\n it as internal low-level.\nSynonyms:\nsketch.create_cache\nsketch create_cache","url":"sketch.html#create_cache"},{"doc":"sketch","title":"cursor","content":"pub fn cursor(cursor: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.cursor\nsketch cursor","url":"sketch.html#cursor"},{"doc":"sketch","title":"direction","content":"pub fn direction(direction: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.direction\nsketch direction","url":"sketch.html#direction"},{"doc":"sketch","title":"disabled","content":"pub fn disabled(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.disabled\nsketch disabled","url":"sketch.html#disabled"},{"doc":"sketch","title":"display","content":"pub fn display(display: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.display\nsketch display","url":"sketch.html#display"},{"doc":"sketch","title":"dynamic","content":"pub fn dynamic(id: String, styles: List(Style(a, b))) -&gt; Class\n Compiles a dynamic class. It means during the render, when the class with the id\n is re-computed, a new version will be pushed in the browser if needed.\n It means you can reuse the function to output different classes with the same\n function and basis. With a `class`, once computed once during the render, it&#39;s\n not possible to change the content of the class.\n Be careful to add a unique ID: right now, it&#39;s not possible to push\n a dynamic class in the browser without defining an ID. The ID should be unique\n to the computed class, otherwise you could end up with some classes overlap.\nSynonyms:\nsketch.dynamic\nsketch dynamic","url":"sketch.html#dynamic"},{"doc":"sketch","title":"enabled","content":"pub fn enabled(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.enabled\nsketch enabled","url":"sketch.html#enabled"},{"doc":"sketch","title":"filter","content":"pub fn filter(filter: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.filter\nsketch filter","url":"sketch.html#filter"},{"doc":"sketch","title":"first_child","content":"pub fn first_child(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.first_child\nsketch first_child","url":"sketch.html#first_child"},{"doc":"sketch","title":"first_of_type","content":"pub fn first_of_type(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.first_of_type\nsketch first_of_type","url":"sketch.html#first_of_type"},{"doc":"sketch","title":"flex","content":"pub fn flex(flex: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.flex\nsketch flex","url":"sketch.html#flex"},{"doc":"sketch","title":"flex_basis","content":"pub fn flex_basis(flex_basis: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.flex_basis\nsketch flex_basis","url":"sketch.html#flex_basis"},{"doc":"sketch","title":"flex_direction","content":"pub fn flex_direction(flex_direction: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.flex_direction\nsketch flex_direction","url":"sketch.html#flex_direction"},{"doc":"sketch","title":"flex_grow","content":"pub fn flex_grow(flex_grow: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.flex_grow\nsketch flex_grow","url":"sketch.html#flex_grow"},{"doc":"sketch","title":"float","content":"pub fn float(float: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.float\nsketch float","url":"sketch.html#float"},{"doc":"sketch","title":"focus","content":"pub fn focus(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.focus\nsketch focus","url":"sketch.html#focus"},{"doc":"sketch","title":"focus_visible","content":"pub fn focus_visible(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.focus_visible\nsketch focus_visible","url":"sketch.html#focus_visible"},{"doc":"sketch","title":"focus_within","content":"pub fn focus_within(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.focus_within\nsketch focus_within","url":"sketch.html#focus_within"},{"doc":"sketch","title":"font_family","content":"pub fn font_family(font_family: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.font_family\nsketch font_family","url":"sketch.html#font_family"},{"doc":"sketch","title":"font_size","content":"pub fn font_size(font_size: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.font_size\nsketch font_size","url":"sketch.html#font_size"},{"doc":"sketch","title":"font_size_","content":"pub fn font_size_(font_size: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.font_size_\nsketch font_size_","url":"sketch.html#font_size_"},{"doc":"sketch","title":"font_style","content":"pub fn font_style(font_style: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.font_style\nsketch font_style","url":"sketch.html#font_style"},{"doc":"sketch","title":"font_weight","content":"pub fn font_weight(font_weight: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.font_weight\nsketch font_weight","url":"sketch.html#font_weight"},{"doc":"sketch","title":"gap","content":"pub fn gap(gap: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.gap\nsketch gap","url":"sketch.html#gap"},{"doc":"sketch","title":"gap_","content":"pub fn gap_(gap: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.gap_\nsketch gap_","url":"sketch.html#gap_"},{"doc":"sketch","title":"grid_area","content":"pub fn grid_area(grid_area: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.grid_area\nsketch grid_area","url":"sketch.html#grid_area"},{"doc":"sketch","title":"grid_auto_columns","content":"pub fn grid_auto_columns(\n  grid_auto_columns: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.grid_auto_columns\nsketch grid_auto_columns","url":"sketch.html#grid_auto_columns"},{"doc":"sketch","title":"grid_auto_flow","content":"pub fn grid_auto_flow(grid_auto_flow: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.grid_auto_flow\nsketch grid_auto_flow","url":"sketch.html#grid_auto_flow"},{"doc":"sketch","title":"grid_auto_rows","content":"pub fn grid_auto_rows(grid_auto_rows: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.grid_auto_rows\nsketch grid_auto_rows","url":"sketch.html#grid_auto_rows"},{"doc":"sketch","title":"grid_column","content":"pub fn grid_column(grid_column: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.grid_column\nsketch grid_column","url":"sketch.html#grid_column"},{"doc":"sketch","title":"grid_row","content":"pub fn grid_row(grid_row: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.grid_row\nsketch grid_row","url":"sketch.html#grid_row"},{"doc":"sketch","title":"grid_template","content":"pub fn grid_template(grid_template: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.grid_template\nsketch grid_template","url":"sketch.html#grid_template"},{"doc":"sketch","title":"grid_template_areas","content":"pub fn grid_template_areas(\n  grid_template_areas: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.grid_template_areas\nsketch grid_template_areas","url":"sketch.html#grid_template_areas"},{"doc":"sketch","title":"grid_template_columns","content":"pub fn grid_template_columns(\n  grid_template_columns: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.grid_template_columns\nsketch grid_template_columns","url":"sketch.html#grid_template_columns"},{"doc":"sketch","title":"grid_template_rows","content":"pub fn grid_template_rows(\n  grid_template_rows: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.grid_template_rows\nsketch grid_template_rows","url":"sketch.html#grid_template_rows"},{"doc":"sketch","title":"height","content":"pub fn height(height: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.height\nsketch height","url":"sketch.html#height"},{"doc":"sketch","title":"height_","content":"pub fn height_(height: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.height_\nsketch height_","url":"sketch.html#height_"},{"doc":"sketch","title":"hover","content":"pub fn hover(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.hover\nsketch hover","url":"sketch.html#hover"},{"doc":"sketch","title":"important","content":"pub fn important(style: Style(a, b)) -&gt; Style(a, b)\n Add an `!important` flag to any CSS property.\n It won&#39;t have any effect on non-property style, like media, etc. It will\n then act as the `identity` function.\nSynonyms:\nsketch.important\nsketch important","url":"sketch.html#important"},{"doc":"sketch","title":"invalid","content":"pub fn invalid(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.invalid\nsketch invalid","url":"sketch.html#invalid"},{"doc":"sketch","title":"justify_content","content":"pub fn justify_content(justify: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.justify_content\nsketch justify_content","url":"sketch.html#justify_content"},{"doc":"sketch","title":"justify_items","content":"pub fn justify_items(justify: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.justify_items\nsketch justify_items","url":"sketch.html#justify_items"},{"doc":"sketch","title":"justify_self","content":"pub fn justify_self(justify: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.justify_self\nsketch justify_self","url":"sketch.html#justify_self"},{"doc":"sketch","title":"justify_tracks","content":"pub fn justify_tracks(justify: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.justify_tracks\nsketch justify_tracks","url":"sketch.html#justify_tracks"},{"doc":"sketch","title":"last_child","content":"pub fn last_child(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.last_child\nsketch last_child","url":"sketch.html#last_child"},{"doc":"sketch","title":"last_of_type","content":"pub fn last_of_type(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.last_of_type\nsketch last_of_type","url":"sketch.html#last_of_type"},{"doc":"sketch","title":"left","content":"pub fn left(size: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.left\nsketch left","url":"sketch.html#left"},{"doc":"sketch","title":"left_","content":"pub fn left_(size: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.left_\nsketch left_","url":"sketch.html#left_"},{"doc":"sketch","title":"letter_spacing","content":"pub fn letter_spacing(letter_spacing: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.letter_spacing\nsketch letter_spacing","url":"sketch.html#letter_spacing"},{"doc":"sketch","title":"line_break","content":"pub fn line_break(line_break: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.line_break\nsketch line_break","url":"sketch.html#line_break"},{"doc":"sketch","title":"line_height","content":"pub fn line_height(line_height: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.line_height\nsketch line_height","url":"sketch.html#line_height"},{"doc":"sketch","title":"link","content":"pub fn link(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.link\nsketch link","url":"sketch.html#link"},{"doc":"sketch","title":"list_style","content":"pub fn list_style(list_style: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.list_style\nsketch list_style","url":"sketch.html#list_style"},{"doc":"sketch","title":"list_style_image","content":"pub fn list_style_image(list_style_image: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.list_style_image\nsketch list_style_image","url":"sketch.html#list_style_image"},{"doc":"sketch","title":"list_style_position","content":"pub fn list_style_position(\n  list_style_position: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.list_style_position\nsketch list_style_position","url":"sketch.html#list_style_position"},{"doc":"sketch","title":"list_style_type","content":"pub fn list_style_type(list_style_type: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.list_style_type\nsketch list_style_type","url":"sketch.html#list_style_type"},{"doc":"sketch","title":"lustre_setup","content":"pub fn lustre_setup(\n  options: Options,\n) -&gt; Result(fn(fn(a) -&gt; b) -&gt; fn(a) -&gt; b, SketchError)\n\nSynonyms:\nsketch.lustre_setup\nsketch lustre_setup","url":"sketch.html#lustre_setup"},{"doc":"sketch","title":"margin","content":"pub fn margin(margin: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.margin\nsketch margin","url":"sketch.html#margin"},{"doc":"sketch","title":"margin_","content":"pub fn margin_(margin: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.margin_\nsketch margin_","url":"sketch.html#margin_"},{"doc":"sketch","title":"margin_bottom","content":"pub fn margin_bottom(margin: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.margin_bottom\nsketch margin_bottom","url":"sketch.html#margin_bottom"},{"doc":"sketch","title":"margin_left","content":"pub fn margin_left(margin: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.margin_left\nsketch margin_left","url":"sketch.html#margin_left"},{"doc":"sketch","title":"margin_right","content":"pub fn margin_right(margin: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.margin_right\nsketch margin_right","url":"sketch.html#margin_right"},{"doc":"sketch","title":"margin_top","content":"pub fn margin_top(margin: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.margin_top\nsketch margin_top","url":"sketch.html#margin_top"},{"doc":"sketch","title":"max_height","content":"pub fn max_height(height: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.max_height\nsketch max_height","url":"sketch.html#max_height"},{"doc":"sketch","title":"max_height_","content":"pub fn max_height_(height: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.max_height_\nsketch max_height_","url":"sketch.html#max_height_"},{"doc":"sketch","title":"max_width","content":"pub fn max_width(width: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.max_width\nsketch max_width","url":"sketch.html#max_width"},{"doc":"sketch","title":"max_width_","content":"pub fn max_width_(width: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.max_width_\nsketch max_width_","url":"sketch.html#max_width_"},{"doc":"sketch","title":"media","content":"pub fn media(\n  query: Query,\n  styles: List(Style(NoMedia, PseudoSelector)),\n) -&gt; Style(Media, a)\n\nSynonyms:\nsketch.media\nsketch media","url":"sketch.html#media"},{"doc":"sketch","title":"memo","content":"pub fn memo(class: Class) -&gt; Class\n Memoizes a function across multiple renders. When encountered for the first time,\n the class will be put in long-live section of the stylesheet. Once in long-live\n section, the computed class will never be garbaged, and will be included in every\n render.\n This saves some time during render by skipping every memoized class. You can use it\n when you know that a class will be used during every render, or when you want\n a class to not be forgetted, because you&#39;re using it often.\nSynonyms:\nsketch.memo\nsketch memo","url":"sketch.html#memo"},{"doc":"sketch","title":"min_height","content":"pub fn min_height(height: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.min_height\nsketch min_height","url":"sketch.html#min_height"},{"doc":"sketch","title":"min_height_","content":"pub fn min_height_(height: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.min_height_\nsketch min_height_","url":"sketch.html#min_height_"},{"doc":"sketch","title":"min_width","content":"pub fn min_width(width: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.min_width\nsketch min_width","url":"sketch.html#min_width"},{"doc":"sketch","title":"min_width_","content":"pub fn min_width_(width: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.min_width_\nsketch min_width_","url":"sketch.html#min_width_"},{"doc":"sketch","title":"nth_child","content":"pub fn nth_child(\n  selector: String,\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.nth_child\nsketch nth_child","url":"sketch.html#nth_child"},{"doc":"sketch","title":"nth_last_child","content":"pub fn nth_last_child(\n  selector: String,\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.nth_last_child\nsketch nth_last_child","url":"sketch.html#nth_last_child"},{"doc":"sketch","title":"nth_last_of_type","content":"pub fn nth_last_of_type(\n  selector: String,\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.nth_last_of_type\nsketch nth_last_of_type","url":"sketch.html#nth_last_of_type"},{"doc":"sketch","title":"nth_of_type","content":"pub fn nth_of_type(\n  selector: String,\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.nth_of_type\nsketch nth_of_type","url":"sketch.html#nth_of_type"},{"doc":"sketch","title":"object_fit","content":"pub fn object_fit(object_fit: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.object_fit\nsketch object_fit","url":"sketch.html#object_fit"},{"doc":"sketch","title":"object_position","content":"pub fn object_position(object_position: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.object_position\nsketch object_position","url":"sketch.html#object_position"},{"doc":"sketch","title":"offset","content":"pub fn offset(offset: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.offset\nsketch offset","url":"sketch.html#offset"},{"doc":"sketch","title":"offset_anchor","content":"pub fn offset_anchor(offset_anchor: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.offset_anchor\nsketch offset_anchor","url":"sketch.html#offset_anchor"},{"doc":"sketch","title":"offset_distance","content":"pub fn offset_distance(offset_distance: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.offset_distance\nsketch offset_distance","url":"sketch.html#offset_distance"},{"doc":"sketch","title":"offset_path","content":"pub fn offset_path(offset_path: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.offset_path\nsketch offset_path","url":"sketch.html#offset_path"},{"doc":"sketch","title":"offset_position","content":"pub fn offset_position(offset_position: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.offset_position\nsketch offset_position","url":"sketch.html#offset_position"},{"doc":"sketch","title":"offset_rotate","content":"pub fn offset_rotate(offset_rotate: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.offset_rotate\nsketch offset_rotate","url":"sketch.html#offset_rotate"},{"doc":"sketch","title":"only_child","content":"pub fn only_child(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.only_child\nsketch only_child","url":"sketch.html#only_child"},{"doc":"sketch","title":"only_of_type","content":"pub fn only_of_type(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.only_of_type\nsketch only_of_type","url":"sketch.html#only_of_type"},{"doc":"sketch","title":"opacity","content":"pub fn opacity(opacity: Float) -&gt; Style(a, b)\n\nSynonyms:\nsketch.opacity\nsketch opacity","url":"sketch.html#opacity"},{"doc":"sketch","title":"optional","content":"pub fn optional(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.optional\nsketch optional","url":"sketch.html#optional"},{"doc":"sketch","title":"outline","content":"pub fn outline(outline: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.outline\nsketch outline","url":"sketch.html#outline"},{"doc":"sketch","title":"outline_color","content":"pub fn outline_color(outline_color: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.outline_color\nsketch outline_color","url":"sketch.html#outline_color"},{"doc":"sketch","title":"outline_offset","content":"pub fn outline_offset(outline_offset: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.outline_offset\nsketch outline_offset","url":"sketch.html#outline_offset"},{"doc":"sketch","title":"outline_style","content":"pub fn outline_style(outline_style: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.outline_style\nsketch outline_style","url":"sketch.html#outline_style"},{"doc":"sketch","title":"outline_width","content":"pub fn outline_width(outline_width: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.outline_width\nsketch outline_width","url":"sketch.html#outline_width"},{"doc":"sketch","title":"overflow","content":"pub fn overflow(overflow: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.overflow\nsketch overflow","url":"sketch.html#overflow"},{"doc":"sketch","title":"overflow_x","content":"pub fn overflow_x(overflow_x: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.overflow_x\nsketch overflow_x","url":"sketch.html#overflow_x"},{"doc":"sketch","title":"overflow_y","content":"pub fn overflow_y(overflow_y: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.overflow_y\nsketch overflow_y","url":"sketch.html#overflow_y"},{"doc":"sketch","title":"padding","content":"pub fn padding(padding: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.padding\nsketch padding","url":"sketch.html#padding"},{"doc":"sketch","title":"padding_","content":"pub fn padding_(padding: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.padding_\nsketch padding_","url":"sketch.html#padding_"},{"doc":"sketch","title":"padding_bottom","content":"pub fn padding_bottom(padding: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.padding_bottom\nsketch padding_bottom","url":"sketch.html#padding_bottom"},{"doc":"sketch","title":"padding_left","content":"pub fn padding_left(padding: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.padding_left\nsketch padding_left","url":"sketch.html#padding_left"},{"doc":"sketch","title":"padding_right","content":"pub fn padding_right(padding: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.padding_right\nsketch padding_right","url":"sketch.html#padding_right"},{"doc":"sketch","title":"padding_top","content":"pub fn padding_top(padding: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.padding_top\nsketch padding_top","url":"sketch.html#padding_top"},{"doc":"sketch","title":"place_content","content":"pub fn place_content(place: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.place_content\nsketch place_content","url":"sketch.html#place_content"},{"doc":"sketch","title":"place_items","content":"pub fn place_items(place: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.place_items\nsketch place_items","url":"sketch.html#place_items"},{"doc":"sketch","title":"place_self","content":"pub fn place_self(place: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.place_self\nsketch place_self","url":"sketch.html#place_self"},{"doc":"sketch","title":"placeholder","content":"pub fn placeholder(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.placeholder\nsketch placeholder","url":"sketch.html#placeholder"},{"doc":"sketch","title":"pointer_events","content":"pub fn pointer_events(pointer_events: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.pointer_events\nsketch pointer_events","url":"sketch.html#pointer_events"},{"doc":"sketch","title":"position","content":"pub fn position(position: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.position\nsketch position","url":"sketch.html#position"},{"doc":"sketch","title":"prepare","content":"pub fn prepare(cache: Cache) -&gt; Nil\n Lifecycle function — not side-effect free\n `prepare` should be called before your repaint, and before the different\n calls to [`class`](#class) and [`dynamic`](#dynamic) functions. This setups\n the cache to prepare for a new paint, and will allow for diffing the styles.\n As long as you don&#39;t call `prepare`, the stylesheet output by sketch will not\n diff, and you&#39;ll use the stylesheet as append-only. This could be done at\n will.\n Be careful, the styles computed by [`class`](#class) and [`dynamic`](#dynamic)\n will be pushed in the last cache called by `prepare`, due to the styles\n handling (and some side-effects under-the-hood for performance purposes).\nSynonyms:\nsketch.prepare\nsketch prepare","url":"sketch.html#prepare"},{"doc":"sketch","title":"property","content":"pub fn property(field: String, content: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.property\nsketch property","url":"sketch.html#property"},{"doc":"sketch","title":"pseudo_selector","content":"pub fn pseudo_selector(\n  value: String,\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.pseudo_selector\nsketch pseudo_selector","url":"sketch.html#pseudo_selector"},{"doc":"sketch","title":"read_only","content":"pub fn read_only(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.read_only\nsketch read_only","url":"sketch.html#read_only"},{"doc":"sketch","title":"read_write","content":"pub fn read_write(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.read_write\nsketch read_write","url":"sketch.html#read_write"},{"doc":"sketch","title":"render","content":"pub fn render(cache: Cache) -&gt; Result(String, Nil)\n Lifecycle function — not side-effect free\n `render` takes a Cache, and render its content to the stylesheet, according\n to the choice of the Cache. `render` is idempotent, and can be called as\n much as you want.\n You can expect `render` to return Ok(String) representing the stylesheet on\n BEAM, and Error(Nil) on JS. It means there&#39;s not output String in JS, but the\n modification happened in the DOM!\nSynonyms:\nsketch.render\nsketch render","url":"sketch.html#render"},{"doc":"sketch","title":"required","content":"pub fn required(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.required\nsketch required","url":"sketch.html#required"},{"doc":"sketch","title":"right","content":"pub fn right(size: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.right\nsketch right","url":"sketch.html#right"},{"doc":"sketch","title":"right_","content":"pub fn right_(size: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.right_\nsketch right_","url":"sketch.html#right_"},{"doc":"sketch","title":"row_gap","content":"pub fn row_gap(row_gap: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.row_gap\nsketch row_gap","url":"sketch.html#row_gap"},{"doc":"sketch","title":"target","content":"pub fn target(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.target\nsketch target","url":"sketch.html#target"},{"doc":"sketch","title":"text_align","content":"pub fn text_align(text_align: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.text_align\nsketch text_align","url":"sketch.html#text_align"},{"doc":"sketch","title":"text_decoration","content":"pub fn text_decoration(text_decoration: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.text_decoration\nsketch text_decoration","url":"sketch.html#text_decoration"},{"doc":"sketch","title":"text_justify","content":"pub fn text_justify(text_justify: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.text_justify\nsketch text_justify","url":"sketch.html#text_justify"},{"doc":"sketch","title":"text_overflow","content":"pub fn text_overflow(text_overflow: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.text_overflow\nsketch text_overflow","url":"sketch.html#text_overflow"},{"doc":"sketch","title":"text_transform","content":"pub fn text_transform(text_transform: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.text_transform\nsketch text_transform","url":"sketch.html#text_transform"},{"doc":"sketch","title":"to_class_name","content":"pub fn to_class_name(class: Class) -&gt; String\n Convert a `Class` to its proper class name, to use it anywhere in your\n application. It can have the form `class1` or `class1 class2` in case of\n classes composition.\nSynonyms:\nsketch.to_class_name\nsketch to_class_name","url":"sketch.html#to_class_name"},{"doc":"sketch","title":"to_lustre","content":"pub fn to_lustre(class: Class) -&gt; Attribute(a)\n Convert a `Class` to its equivalent lustre attribute. Use it in your\n view functions. I.e. `html.div([sketch.to_lustre(class())], [])`.\nSynonyms:\nsketch.to_lustre\nsketch to_lustre","url":"sketch.html#to_lustre"},{"doc":"sketch","title":"top","content":"pub fn top(size: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.top\nsketch top","url":"sketch.html#top"},{"doc":"sketch","title":"top_","content":"pub fn top_(size: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.top_\nsketch top_","url":"sketch.html#top_"},{"doc":"sketch","title":"transform","content":"pub fn transform(transform: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.transform\nsketch transform","url":"sketch.html#transform"},{"doc":"sketch","title":"transform_box","content":"pub fn transform_box(transform_box: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.transform_box\nsketch transform_box","url":"sketch.html#transform_box"},{"doc":"sketch","title":"transform_origin","content":"pub fn transform_origin(transform_origin: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.transform_origin\nsketch transform_origin","url":"sketch.html#transform_origin"},{"doc":"sketch","title":"transform_style","content":"pub fn transform_style(transform_style: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.transform_style\nsketch transform_style","url":"sketch.html#transform_style"},{"doc":"sketch","title":"transition","content":"pub fn transition(transition: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.transition\nsketch transition","url":"sketch.html#transition"},{"doc":"sketch","title":"translate","content":"pub fn translate(translate: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.translate\nsketch translate","url":"sketch.html#translate"},{"doc":"sketch","title":"user_select","content":"pub fn user_select(user_select: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.user_select\nsketch user_select","url":"sketch.html#user_select"},{"doc":"sketch","title":"valid","content":"pub fn valid(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.valid\nsketch valid","url":"sketch.html#valid"},{"doc":"sketch","title":"visibility","content":"pub fn visibility(visibility: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.visibility\nsketch visibility","url":"sketch.html#visibility"},{"doc":"sketch","title":"visited","content":"pub fn visited(\n  styles: List(Style(NoMedia, NoPseudoSelector)),\n) -&gt; Style(a, PseudoSelector)\n\nSynonyms:\nsketch.visited\nsketch visited","url":"sketch.html#visited"},{"doc":"sketch","title":"white_space","content":"pub fn white_space(white_space: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.white_space\nsketch white_space","url":"sketch.html#white_space"},{"doc":"sketch","title":"white_space_collapse","content":"pub fn white_space_collapse(\n  white_space_collapse: String,\n) -&gt; Style(a, b)\n\nSynonyms:\nsketch.white_space_collapse\nsketch white_space_collapse","url":"sketch.html#white_space_collapse"},{"doc":"sketch","title":"width","content":"pub fn width(width: Size) -&gt; Style(a, b)\n\nSynonyms:\nsketch.width\nsketch width","url":"sketch.html#width"},{"doc":"sketch","title":"width_","content":"pub fn width_(width: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.width_\nsketch width_","url":"sketch.html#width_"},{"doc":"sketch","title":"word_break","content":"pub fn word_break(word_break: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.word_break\nsketch word_break","url":"sketch.html#word_break"},{"doc":"sketch","title":"word_spacing","content":"pub fn word_spacing(word_spacing: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.word_spacing\nsketch word_spacing","url":"sketch.html#word_spacing"},{"doc":"sketch","title":"word_wrap","content":"pub fn word_wrap(word_wrap: String) -&gt; Style(a, b)\n\nSynonyms:\nsketch.word_wrap\nsketch word_wrap","url":"sketch.html#word_wrap"},{"doc":"sketch","title":"z_index","content":"pub fn z_index(z_index: Int) -&gt; Style(a, b)\n\nSynonyms:\nsketch.z_index\nsketch z_index","url":"sketch.html#z_index"},{"doc":"sketch","title":"sketch","content":" Want to know more about details? Go to the\n [additional docs](https://hexdocs.pm/sketch/internal-details.html)!\n\n ---\n\n # Table of Contents\n\n - Setup and usage\n   - [`class`](#class)\n   - [`dynamic`](#dynamic)\n   - [`memo`](#memo)\n   - [`to_class_name`](#to_class_name)\n   - [`to_lustre`](#to_lustre)\n\n - Lifecycle functions\n   - [`create_cache`](#create_cache)\n   - [`prepare`](#prepare)\n   - [`render`](#render)\n\n - Modifiers\n   - [`important`](#important)\n   - [`compose`](#compose)\n\n - Media Queries\n   - [`media`](#media)\n\n - Properties\n   - [`width`](#width)\n   - [`width_`](#width_)\n   - [`max_width`](#max_width)\n   - [`max_width_`](#max_width_)\n   - [`min_width`](#min_width)\n   - [`min_width_`](#min_width_)\n   - [`height`](#height)\n   - [`height_`](#height_)\n   - [`max_height`](#max_height)\n   - [`max_height_`](#max_height_)\n   - [`min_height`](#min_height)\n   - [`min_height_`](#min_height_)\n   - [`color`](#color)\n   - [`font_family`](#font_family)\n   - [`font_style`](#font_style)\n   - [`font_size`](#font_size)\n   - [`font_size_`](#font_size_)\n   - [`font_weight`](#font_weight)\n   - [`letter_spacing`](#letter_spacing)\n   - [`line_break`](#line_break)\n   - [`line_height`](#line_height)\n   - [`text_align`](#text_align)\n   - [`text_decoration`](#text_decoration)\n   - [`text_justify`](#text_justify)\n   - [`text_overflow`](#text_overflow)\n   - [`text_transform`](#text_transform)\n   - [`white_space`](#white_space)\n   - [`white_space_collapse`](#white_space_collapse)\n   - [`word_break`](#word_break)\n   - [`word_spacing`](#word_spacing)\n   - [`word_wrap`](#word_wrap)\n   - [`list_style`](#list_style)\n   - [`list_style_image`](#list_style_image)\n   - [`list_style_position`](#list_style_position)\n   - [`list_style_type`](#list_style_type)\n   - [`display`](#display)\n   - [`z_index`](#z_index)\n   - [`visibility`](#visibility)\n   - [`background`](#background)\n   - [`object_fit`](#object_fit)\n   - [`object_position`](#object_position)\n   - [`opacity`](#opacity)\n   - [`pointer_events`](#pointer_events)\n   - [`user_select`](#user_select)\n   - [`position`](#position)\n   - [`outline`](#outline)\n   - [`outline_color`](#outline_color)\n   - [`outline_offset`](#outline_offset)\n   - [`outline_style`](#outline_style)\n   - [`outline_width`](#outline_width)\n   - [`offset`](#offset)\n   - [`offset_anchor`](#offset_anchor)\n   - [`offset_distance`](#offset_distance)\n   - [`offset_path`](#offset_path)\n   - [`offset_position`](#offset_position)\n   - [`offset_rotate`](#offset_rotate)\n   - [`gap`](#gap)\n   - [`gap_`](#gap_)\n   - [`column_gap`](#column_gap)\n   - [`row_gap`](#row_gap)\n   - [`grid_area`](#grid_area)\n   - [`grid_column`](#grid_column)\n   - [`grid_row`](#grid_row)\n   - [`grid_template`](#grid_template)\n   - [`grid_auto_columns`](#grid_auto_columns)\n   - [`grid_auto_rows`](#grid_auto_rows)\n   - [`grid_auto_flow`](#grid_auto_flow)\n   - [`grid_template_areas`](#grid_template_areas)\n   - [`grid_template_columns`](#grid_template_columns)\n   - [`grid_template_rows`](#grid_template_rows)\n   - [`align_content`](#align_content)\n   - [`align_items`](#align_items)\n   - [`align_self`](#align_self)\n   - [`align_tracks`](#align_tracks)\n   - [`justify_content`](#justify_content)\n   - [`justify_items`](#justify_items)\n   - [`justify_self`](#justify_self)\n   - [`justify_tracks`](#justify_tracks)\n   - [`place_content`](#place_content)\n   - [`place_items`](#place_items)\n   - [`place_self`](#place_self)\n   - [`animation`](#animation)\n   - [`animation_name`](#animation_name)\n   - [`animation_duration`](#animation_duration)\n   - [`animation_timing_function`](#animation_timing_function)\n   - [`animation_delay`](#animation_delay)\n   - [`animation_iteration_count`](#animation_iteration_count)\n   - [`animation_direction`](#animation_direction)\n   - [`animation_fill_mode`](#animation_fill_mode)\n   - [`animation_play_state`](#animation_play_state)\n   - [`transition`](#transition)\n   - [`translate`](#translate)\n   - [`transform`](#transform)\n   - [`transform_box`](#transform_box)\n   - [`transform_origin`](#transform_origin)\n   - [`transform_style`](#transform_style)\n   - [`appearance`](#appearance)\n   - [`filter`](#filter)\n   - [`aspect_ratio`](#aspect_ratio)\n   - [`top`](#top)\n   - [`bottom`](#bottom)\n   - [`right`](#right)\n   - [`left`](#left)\n   - [`top_`](#top_)\n   - [`bottom_`](#bottom_)\n   - [`right_`](#right_)\n   - [`left_`](#left_)\n   - [`box_shadow`](#box_shadow)\n   - [`box_sizing`](#box_sizing)\n   - [`overflow`](#overflow)\n   - [`overflow_x`](#overflow_x)\n   - [`overflow_y`](#overflow_y)\n   - [`direction`](#direction)\n   - [`flex`](#flex)\n   - [`flex_basis`](#flex_basis)\n   - [`flex_direction`](#flex_direction)\n   - [`flex_grow`](#flex_grow)\n   - [`border`](#border)\n   - [`border_top`](#border_top)\n   - [`border_bottom`](#border_bottom)\n   - [`border_right`](#border_right)\n   - [`border_left`](#border_left)\n   - [`border_radius`](#border_radius)\n   - [`border_radius_`](#border_radius_)\n   - [`border_top_right_radius`](#border_top_right_radius)\n   - [`border_top_right_radius_`](#border_top_right_radius_)\n   - [`border_top_left_radius`](#border_top_left_radius)\n   - [`border_top_left_radius_`](#border_top_left_radius_)\n   - [`border_bottom_right_radius`](#border_bottom_right_radius)\n   - [`border_bottom_right_radius_`](#border_bottom_right_radius_)\n   - [`border_bottom_left_radius`](#border_bottom_left_radius)\n   - [`border_bottom_left_radius_`](#border_bottom_left_radius_)\n   - [`padding`](#padding)\n   - [`padding_`](#padding_)\n   - [`padding_top`](#padding_top)\n   - [`padding_bottom`](#padding_bottom)\n   - [`padding_right`](#padding_right)\n   - [`padding_left`](#padding_left)\n   - [`margin`](#margin)\n   - [`margin_`](#margin_)\n   - [`margin_top`](#margin_top)\n   - [`margin_bottom`](#margin_bottom)\n   - [`margin_right`](#margin_right)\n   - [`margin_left`](#margin_left)\n   - [`cursor`](#cursor)\n   - [`float`](#float)\n   - [`property`](#property)\n\n - Pseudo-selectors\n   - [`placeholder`](#placeholder)\n   - [`hover`](#hover)\n   - [`active`](#active)\n   - [`focus`](#focus)\n   - [`focus_visible`](#focus_visible)\n   - [`focus_within`](#focus_within)\n   - [`enabled`](#enabled)\n   - [`disabled`](#disabled)\n   - [`read_only`](#read_only)\n   - [`read_write`](#read_write)\n   - [`checked`](#checked)\n   - [`blank`](#blank)\n   - [`valid`](#valid)\n   - [`invalid`](#invalid)\n   - [`required`](#required)\n   - [`optional`](#optional)\n   - [`link`](#link)\n   - [`visited`](#visited)\n   - [`target`](#target)\n   - [`nth_child`](#nth_child)\n   - [`nth_last_child`](#nth_last_child)\n   - [`nth_of_type`](#nth_of_type)\n   - [`nth_last_of_type`](#nth_last_of_type)\n   - [`first_child`](#first_child)\n   - [`last_child`](#last_child)\n   - [`only_child`](#only_child)\n   - [`first_of_type`](#first_of_type)\n   - [`last_of_type`](#last_of_type)\n   - [`only_of_type`](#only_of_type)","url":"sketch.html"},{"doc":"sketch/lustre","title":"compose","content":"pub fn compose(\n  view: fn(a) -&gt; Element(b),\n  cache: Cache,\n) -&gt; fn(a) -&gt; Element(b)\n Wrap the view function in lustre. Be careful, on BEAM, sketch will add an\n additional `div` at the root of the HTML tree, to inject the styles in the app.\n This should have no impact on your app.\nSynonyms:\nsketch/lustre.compose\nsketch/lustre compose","url":"sketch/lustre.html#compose"},{"doc":"sketch/lustre","title":"setup","content":"pub fn setup(options: Options) -&gt; Result(Cache, SketchError)\n setup is a shortcut for `sketch.create_cache`.\n It simplify usage for lustre.\nSynonyms:\nsketch/lustre.setup\nsketch/lustre setup","url":"sketch/lustre.html#setup"},{"doc":"sketch/lustre","title":"ssr","content":"pub fn ssr(el: Element(a), cache: Cache) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre.ssr\nsketch/lustre ssr","url":"sketch/lustre.html#ssr"},{"doc":"sketch/lustre","title":"sketch/lustre","content":"","url":"sketch/lustre.html"}]);